@@ -9,6 +9,7 @@ import pandas as pd
 import re
 import requests
 import shutil
+import sys
 from tqdm import tqdm
 from typing import Union, Optional, Callable
 from unicodedata import normalize
@@ -51,7 +52,7 @@ def view_types(data: Union[pd.DataFrame, pd.Series, list, dict], dropna: Optiona
 
     df_output['(unique)'] = [data[c].astype(str).nunique(dropna) for c in data.columns]
     df_output.columns = [columns_exch.get(str(x), x) for x in df_output.columns]
-    if '_Jupyter' in globals():
+    if sys.argv[-1].endswith('json'):
         display(df_output.head(60))
     else:
         print(df_output.head(60))
@@ -77,7 +78,7 @@ def read_urls_contents(
     session : requests.Session, optional
         Auth session.
     parser : function, optional
-        Function for content preprocessing in main thread.
+        Function for content preprocessing in main thread f(decoded_content: str, final_url: str) -> None.
     encoding : str, optional
         Encoding of the content. By default, the content encoding is determined automatically.
     max_retries : int, optional
@@ -103,10 +104,11 @@ def read_urls_contents(
         """
         Default function for url download
         """
+        r = session.get(url, timeout=timeout)
         if encoding is None:
-            return session.get(url, timeout=timeout).text
+            return r.text, r.url
         else:
-            return session.get(url, timeout=timeout).content.decode(encoding)
+            return r.content.decode(encoding), r.url
 
     if mute == 'tqdm':
         it = tqdm
@@ -144,9 +146,9 @@ def read_urls_contents(
             url = future_load_url[future]
             try:
                 if output_type is None:
-                    parser(future.result(), url)
+                    parser(*future.result())
                 else:
-                    buf.write(future.result() if parser is None else parser(future.result(), url))
+                    buf.write(future.result()[0] if parser is None else parser(*future.result()))
             except Exception as exc:
                 if error_page_output is None:
                     raise Exception(f'Download error\n{url}|{exc}')
